@@ -10,7 +10,7 @@ use RPi::WiringPi::LCD;
 use RPi::WiringPi::Pin;
 use RPi::WiringPi::Interrupt;
 
-our $VERSION = '0.99_05';
+our $VERSION = '0.99_06';
 
 my $fatal_exit = 1;
 
@@ -18,7 +18,7 @@ BEGIN {
     sub error {
         my $err = shift;
         print "\ndie() caught... ".  __PACKAGE__ ." is cleaning up\n",
-        _shutdown();
+        RPi::WiringPi::Util::cleanup();
         print "\ncleaned up, exiting...\n";
         print "\noriginal error: $err\n";
         exit if $fatal_exit;
@@ -43,11 +43,11 @@ sub new {
             $self->pin_scheme($scheme);
         }
         else {
-            # we default to sys mode
+            # we default to gpio mode
 
             if (! defined $self->{setup}) {
-                $self->SUPER::setup_sys();
-                $self->pin_scheme(RPI_MODE_WPI);
+                $self->SUPER::setup_gpio();
+                $self->pin_scheme(RPI_MODE_GPIO);
             }
             else {
                 if ($self->_setup =~ /^s/) {
@@ -81,15 +81,18 @@ sub new {
 }
 sub pin {
     my ($self, $pin_num) = @_;
+
+    my $pins_in_use = $self->registered_pins;
+    my $gpio = $self->pin_to_gpio($pin_num);
+
+    if (defined $ENV{RPI_PINS} && grep {$gpio == $_} split /,/, $pins_in_use){
+        die "\npin $pin_num is already in use... can't create second object\n";
+    }
+
     my $pin = RPi::WiringPi::Pin->new($pin_num);
     $self->register_pin($pin);
     return $pin;
 }
-sub board {
-    my $self = shift;
-    my $board = RPi::WiringPi::Board->new;
-    return $board;
-}
 sub lcd {
     my $self = shift;
     my $lcd = RPi::WiringPi::LCD->new;
@@ -100,6 +103,17 @@ sub interrupt {
     my $interrupt = RPi::WiringPi::Interrupt->new;
     return $interrupt;
 }
+sub rev {
+    return $_[0]->board_rev;
+}
+sub pwm_range {
+    my ($self, $range) = @_;
+    if (defined $range){
+       $self->{pwm_range} = $range;
+        $self->pwm_set_range($range);
+    }
+    return defined $self->{pwm_range} ? $self->{pwm_range} : 1023;
+}
 
 # private
 
@@ -110,16 +124,6 @@ sub _fatal_exit {
 sub _setup {
     return $_[0]->{setup};
 }
-sub _shutdown {
-    # emergency die() handler cleanup
-    if (defined $ENV{RPI_PINS}) {
-        my @pins = split ',', $ENV{RPI_PINS};
-        for (@pins) {
-            #FIXME: WiringPi::API->write_pin( $_, LOW );
-            #FIXME: WiringPi::API->pin_mode( $_, INPUT );
-        }
-    }
-}
 
 sub _vim{1;};
 1;
@@ -137,11 +141,7 @@ various items
 
     my $pi = RPi::WiringPi->new;
 
-    # board
-
-    my $board = $pi->board;
-    my $revision = $pi->rev;
-    print "Raspberry Pi board revision: $revision"\n";
+    my $board_revision = $pi->rev;
 
     # pin
 
@@ -149,6 +149,7 @@ various items
     $pin->mode(OUTPUT);
     $pin->write(ON);
 
+
     my $num = $pin->num;
     my $mode = $pin->mode;
     my $state = $pin->read;
@@ -162,7 +163,7 @@ various items
     # first column, first row
     
     $lcd->position(0, 0); 
-    $lcd->print("Pi rev: $revision");
+    $lcd->print("Pi rev: $board_revision");
 
     # first column, second row
     
@@ -176,26 +177,19 @@ various items
 
 =head1 DESCRIPTION
 
-WARNING: Until version 1.00 is released, the API and other functionality of
-this module may change, and things may break from time-to-time.
-
-IMPORTANT (C<root> vs C<sudo>):
-
-Using this software requires root privileges. There are two separate modes you
-can select from... one where you must run your scripts as C<root>, the other
-where you can use a non-root user. For the latter, we do make a few calls with
-C<sudo>, so when in this mode, your user account must have password-less
-C<sudo> access to at minimum the C<gpio> command line utility. The default user
-account (C<pi>) on Raspbian OS has this right by default. We default to the
-non-root configuration. See the details in the C<new> method below for further
-details.
-
 This is the root module for the C<RPi::WiringPi> system. It interfaces to a
-Raspberry Pi board, its accessories and its GPIO pins via the 
+Raspberry Pi board, its accessories and its GPIO pins via the
 L<wiringPi|http://wiringpi.com> library through the Perl wrapper
 L<WiringPi::API|https://metacpan.org/pod/WiringPi::API>
 module.
 
+The scripts you write using this software requires those scripts to be run
+as root (or with C<sudo>, if configured properly... see 
+L<RPi::WiringPi::Tutorial.pod>.
+
+By default, we set up using the C<GPIO> numbering scheme for pins. See C<new()>
+method for information on how to change this.
+
 This module is essentially a 'manager' for the sub-modules (ie. components).
 You can use the component modules directly, but retrieving components through
 this module instead has many benefits. We maintain a registry of pins and other
@@ -212,7 +206,8 @@ this module.
 It's handy to have access to a pin mapping conversion chart. There's an
 excellent pin scheme map for reference at
 L<pinout.xyz|https://pinout.xyz/pinout/wiringpi>. You can also run
-C<gpio readall> at the command line to get a pin chart.
+C<gpio readall> at the command line to get a pin chart, or from the command
+line, run the C<pinmap> command that was installed by this module.
 
 =head1 OPERATIONAL METHODS
 
@@ -232,32 +227,20 @@ Parameters:
 
 Optional. This option specifies which pin mapping (numbering scheme) to use.
 
-    wiringPi:   wiringPi's numbering
-    physical:   physical pin numbering
-    gpio:       GPIO numbering
-    system:     GPIO numbering (root not required in this mode)
+    wpi:    wiringPi's numbering
+    phys:   physical pin numbering
+    gpio:   GPIO numbering
 
 You can also specify C<none> for testing purposes. This will bypass running
 the setup routines.
 
-!!! C<system> mode uses C<sudo> !!!
-
-C<system> mode is the only mode where you do not need to run your application
-as the C<root> user. To this end, in C<wiringPi> when using C<system> mode,
-you have to export and manually manipulate the pins with the C<gpio>
-application prior to using them. I have wrapped around this limitation by
-making these calls with C<sudo> for you, so that you don't have to do anything
-different no matter the mode you're using.
-
-When using C<system> mode, the user running your application should be able
-to at minimum call the <c>gpio</c> application without supplying a password.
-The default Raspberry Pi user C<pi> can do this by default.
-
 See L<wiringPi setup reference|http://wiringpi.com/reference/setup> for
 important details on the differences.
 
 There's an excellent pin scheme map for reference at
-L<pinout.xyz|https://pinout.xyz/pinout/wiringpi>.
+L<pinout.xyz|https://pinout.xyz/pinout/wiringpi>. You can also run the C<pinmap>
+application that was included in this distribution from the command line to get
+a printout of pin mappings.
 
 =back
 
@@ -286,11 +269,6 @@ Mandatory: The pin number to attach to.
 
 =back
 
-=head2 board()
-
-Returns a L<RPi::WiringPi::Board> object which has access to various
-attributes of the Raspberry Pi physical board itself.
-
 =head2 lcd()
 
 Returns a L<RPi::WiringPi::LCD> object, which allows you to fully manipulate
@@ -302,23 +280,47 @@ Returns a L<RPi::WiringPi::Interrupt> object, which allows you to act when
 certain events occur (eg: a button press). This module is better used through
 the L<RPi::WiringPi::Pin> object.
 
-=head1 IMPORTANT NOTES
+=head2 rev()
 
-=over 4
+Returns the revision of the Pi board.
 
-=item - L<wiringPi|http://wiringpi.com> must be installed prior to
-installing/using this module.
+=head2 pwm_range($range)
 
-=item - By default, we use C<BCM> interpretation of GPIO pin mapping.
-See C<new> method to change this behaviour.
+Changes the range of Pulse Width Modulation (PWM). The default is C<0> through
+C<1023>.
 
-=item - This module hijacks fatal errors with C<$SIG{__DIE__}>, as well as
-C<$SIG{INT}>. This is so that in the case of a fatal error, the Raspberry Pi
-pins are never left in an inconsistent state. By default, we trap the C<die()>,
-reset all pins to their default (INPUT, LOW), then we C<exit()>. Look at the
-C<fatal_exit> param in C<new()> to change the behaviour.
+Parameters:
 
-=back
+    $range
+
+Mandatory: An integer specifying the high-end of the range. The range always
+starts at C<0>. Eg: if C<$range> is C<359>, if you incremented PWM by C<1>
+every second, you'd rotate a step motor one complete rotation in exactly one
+minute.
+
+=head1 RUNNING TESTS
+
+This distribution does not have a typical set of unit tests. This is because to
+ensure proper functionality, you need to be running on a Rasbperry Pi board that
+has a couple of very basic circuits set up.
+
+The tests are in individual Perl scripts inside of the C<test/> directory inside
+this distribution.
+
+Each test, when run without any command line arguments, will print out what you
+need to do. Most tests require a single LED connected to a single GPIO pin, then
+you select the test number to run (1-4) and pass that in as an argument.
+
+The number of the test correlates with a specific setup mode.
+
+Example:
+
+    $ perl test/10-pwm.pl
+
+    need test number as arg: 1-WPI, 2-GPIO, 3-PHYS, 4-SYS
+
+    this test tests the pwm() pin function. Connect an LED to physical pin *12*.
+    The LED should gradually get brighter for each test.
 
 =head1 AUTHOR
 
