@@ -9,7 +9,7 @@ use parent 'RPi::WiringPi::Util';
 use Config;
 use RPi::WiringPi::Constant qw(:all);
 
-our $VERSION = '0.99_05';
+our $VERSION = '0.99_06';
 
 my $interrupts = {};
 
@@ -18,34 +18,9 @@ sub new {
 }
 sub set {
     my ($self, $pin, $edge, $callback) = @_;
-
-    # unset the interrupt if we're changing
-    # it
-
-    if (defined $interrupts->{$pin}{edge}){
-        $self->unset($pin);
-    }
-
     $interrupts->{$pin}{edge} = $edge;
-
     $self->set_interrupt($pin, $edge, $callback);
 }
-sub unset {
-    my ($self, $pin) = @_;
-    if ($pin eq 'all'){
-        for (keys %$interrupts){
-            $self->unset($_);
-        }
-    }
-    else {
-        my $gpio = $self->pin_to_gpio($pin);
-        system "gpio", "edge", $gpio, "none";
-    }
-}
-sub DESTROY {
-    my $self = shift;
-    $self->unset('all');
-}
 
 sub _vim{1;};
 1;
@@ -64,23 +39,22 @@ RPi::WiringPi::Interrupt - Raspberry Pi GPIO pin interrupts
 
     my $pin = 6;
 
-    $int->set($pin, EDGE_HIGH, 'interrupt_handler');
+    $int->set($pin, EDGE_RISING, 'interrupt_handler');
 
     sub interrupt_handler {
         print "in handler";
         # turn a pin on, or do other things
     }
 
-    $int->unset($pin);
-
 =head1 DESCRIPTION
 
 This module allows you to set up, and un-set GPIO pin edge detection
 interrupts where you can supply the name of a Perl subroutine that you write
 that will act as the interrupt handler.
 
-The backend is written in C and is threaded, so it doesn't block the main
-program thread from running while waiting for the interrupt to occur.
+The Interrupt Service Request is written in C and runs in a separate thread, so
+it doesn't block the main program thread from running while waiting for the
+interrupt to occur.
 
 =head1 METHODS
 
@@ -103,7 +77,8 @@ appropriately regardless of which pin mapping you're currently using.
 
     $edge
 
-Mandatory: One of C<1> (LOW), C<2> (HIGH) or C<3> for both HIGH and LOW.
+Mandatory: One of C<1> for C<EDGE_FALLING>, C<2> for C<EDGE_RISING> or C<3> for
+C<EDGE_BOTH>.
 
     $callback
 
@@ -111,21 +86,6 @@ Mandatory: This is the name of a user-written Perl subroutine that contains
 the code you want to execute when the edge change is detected on the pin.
 (ie. the Interrupt Handler).
 
-=head2 unset($pin)
-
-Terminates an interrupt thread, and stops monitoring for more.
-
-Parameters:
-
-    $pin
-
-Mandatory: The pin number. You can also send in C<'all'>, which will disable
-all currently implemented interrupts.
-
-    $edge
-
-Mandatory: see C<set()> for details.
-
 =head1 SEE ALSO
 
 =head1 AUTHOR
