@@ -4,12 +4,13 @@ use strict;
 use warnings;
 
 use parent 'WiringPi::API';
+use parent 'RPi::WiringPi';
 use parent 'RPi::WiringPi::Util';
 
 use RPi::WiringPi::Constant qw(:all);
 use RPi::WiringPi::Interrupt;
 
-our $VERSION = '0.99_05';
+our $VERSION = '0.99_06';
 
 sub new {
     my ($class, $pin) = @_;
@@ -19,11 +20,11 @@ sub new {
     }
 
     my $self = bless {}, $class;
-
+    
     $self->{pin} = $pin;
 
     if ($self->pin_scheme == RPI_MODE_GPIO_SYS){
-        $self->export_pin($pin->num);
+        $self->export_pin($self->num);
     }
     return $self;
 }
@@ -41,10 +42,18 @@ sub mode {
     # shell out to 'gpio' if in SYS mode
 
     if ($self->pin_scheme == RPI_MODE_GPIO_SYS){
-        $mode = 'in'    if $mode == INPUT;
-        $mode = 'out'   if $mode == OUTPUT;
-        $mode = 'pwm'   if $mode == PWM_OUT;
-        $mode = 'clock' if $mode == GPIO_CLOCK;
+        if ($mode == INPUT){
+            $mode = 'in';
+        }
+        elsif ($mode == OUTPUT){
+            $mode = 'out';
+        }
+        elsif ($mode == PWM_OUT){
+            $mode = 'pwm';
+        }
+        elsif ($mode == GPIO_CLOCK){
+            $mode = 'clock';
+        }
 
         my $num = $self->num;
         `sudo gpio -g mode $num $mode`;
@@ -105,13 +114,22 @@ sub pull {
 }
 sub pwm {
     my ($self, $value) = @_;
-    if ($self->mode != 2){
+
+    my $gpio = $self->pin_to_gpio($self->num);
+
+    if ($self->mode != 2 && $gpio == 18){
         my $num = $self->num;
         die "\npin $num isn't set to mode 2 (PWM). pwm() can't be set\n";
     }
+
     if ($value > 1023 || $value < 0){
-        die "Core::pwm_write value must be 0-1023";
+        die "\npwm() value must be 0-1023\n";
     }
+
+    if ($self->pin_scheme == RPI_MODE_GPIO_SYS){
+        die "\nat this time, it isn't possible to use PWM in SYS mode\n";
+    }
+
     $self->pwm_write($self->num, $value);
 }
 sub num {
@@ -119,16 +137,17 @@ sub num {
 }
 sub interrupt_set {
     my ($self, $edge, $callback) = @_;
+    #$self->set_interrupt($self->num, $edge, $callback);
     my $int = RPi::WiringPi::Interrupt->new;
     $int->set($self->num, $edge, $callback);
     $self->{interrupt} = $int;
 }
-sub interrupt_unset {
-    my $self = shift;
-    if (! defined $self->{interrupt}){
-        die "pin " . $self->num ." doesn't have an interrupt to unset\n";
-    }
-    $self->{interrupt}->unset($self->num);
+sub _soft_pwm_enabled {
+    my ($self, $enabled) = @_;
+    $self->{soft_pwm_enabled} = $enabled if defined $enabled;
+    return defined $self->{soft_pwm_enabled}  && $self->{soft_pwm_enabled}
+        ? 1
+        : 0;
 }
 sub _vim{1;};
 1;
@@ -188,24 +207,24 @@ Mandatory: The pin number to attach to.
 
 =head2 mode($mode)
 
-Puts the GPIO pin into either INPUT, OUTPUT, PWM_OUT or GPIO_CLOCK mode. If
-C<$mode> is not sent in, we'll return the pin's current mode.
+Puts the GPIO pin into either C<INPUT>, C<OUTPUT>, C<PWM_OUT> or C<GPIO_CLOCK>
+mode. If C<$mode> is not sent in, we'll return the pin's current mode.
 
 Parameters:
 
     $mode
 
 Optional: If not sent in, we'll simply return the current mode of the pin.
-Otherwise, send in: C<0> for INPUT, C<1> for OUTPUT, C<2> for PWM_OUT and C<3>
-for GPIO_CLOCK (clock) mode.
+Otherwise, send in: C<0> for C<INPUT>, C<1> for C<OUTPUT>, C<2> for CPWM_OUT>
+and C<3> for C<GPIO_CLOCK> (clock) mode.
 
 =head2 read()
 
-Returns C<1> if the pin is HIGH (on) and C<0> if the pin is LOW (off).
+Returns C<1> if the pin is C<HIGH> (on) and C<0> if the pin is C<LOW> (off).
 
 =head2 write($state)
 
-For pins in OUTPUT mode, will turn on (HIGH) the pin, or off (LOW).
+For pins in C<OUTPUT> mode, will turn C<HIGH> (on) the pin, or C<LOW> (off).
 
 Parameters:
 
@@ -222,7 +241,8 @@ Parameter:
 
     $direction
 
-Mandatory: C<2> for UP, C<1> for DOWN and C<0> to turn off the resistor.
+Mandatory: C<2> for C<PUD_UP>, C<1> for C<PUD_DOWN> and C<0> for C<PUD_OFF>
+(disabled the resistor).
 
 =head2 interrupt_set($edge, $callback)
 
@@ -232,7 +252,8 @@ Parameters:
 
     $edge
 
-Mandatory: C<1> (falling), C<2> (rising), or C<3> for both.
+Mandatory: C<1> for C<EDGE_FALLING>, C<2> for C<EDGE_RISING>, or C<3> for
+C<EDGE_BOTH>.
 
     $callback
 
@@ -240,16 +261,11 @@ The string name of a Perl subroutine that you've already written within your
 code. This is the interrupt handler. When an interrupt is triggered, the code
 in this subroutine will run.
 
-=head2 interrupt_unset()
-
-Removes an interrupt from the pin, if set.
-
 =head2 pwm($value)
 
 Sets the level of the Pulse Width Modulation (PWM) of the pin. Dies if the
 pin's C<mode()> is not set to PWM (C<2>). Note that only physical pin 12
-(wiringPi pin 1, GPIO pin 18) is PWM hardware capable. See C<soft_pwm()> to
-use a software-based PWM implementation on all other pins.
+(wiringPi pin 1, GPIO pin 18) is PWM hardware capable. 
 
 Parameter:
 
